@@ -39,6 +39,7 @@
 #include "progcompo.h"
 #include "edcompo.h"
 #include "treeviewcompo.h"
+#include <vdk/vdkhlbutton.h>
 
 static char buff[1024];
 extern char * mini_cfolder_xpm[];
@@ -489,9 +490,9 @@ VDKObject*
 TestvdkForm::CreateButtons(VDKForm* owner)
 {
   int t = 0;
-  VDKTable* table = new VDKTable(owner,5,2,true);
-  // attaches 8 buttons
-  VDKObject* buttons[] = { NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL };
+  VDKTable* table = new VDKTable(owner,6,2,true);
+  // attaches 9 buttons
+  VDKObject* buttons[] = { NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL };
   buttons[0] = new VDKCustomButton(owner,"A _labeled button");
   buttons[0]->Font = new VDKFont(owner,"courier bold 12"); 
   buttons[0]->NormalBackground = clAirBlue;
@@ -526,21 +527,26 @@ TestvdkForm::CreateButtons(VDKForm* owner)
   buttons[7]->ActiveBackground = VDKRgb("sienna");
   buttons[7]->Foreground = "white";
 
+  buttons[8] = new VDKHLButton(owner,"stop.png","An highlighted button");
+  buttons[8]->SetTip("Highlights when mouse is over, grayed on click");
+
   for(t = 0; buttons[t];t++)
     table->AddToCell(buttons[t],t/2,t%2,!GTK_FILL | !GTK_EXPAND,5);
+
   VDKRadioButtonGroup *rbg = new VDKRadioButtonGroup(owner);
   VDKRadioButton* rb = new VDKRadioButton(rbg,"A radio button");
+
   rb->SetTip("radio button group shows an exclusive-or behaviour");
   rb = new VDKRadioButton(rbg,"Another radio button");
   rb->SetTip("radio button group shows an exclusive-or behaviour");
   rb->Foreground = clBlue;
-  table->AddToCell(rbg,4,0,!GTK_FILL | !GTK_EXPAND,5);
+  table->AddToCell(rbg,5,0,!GTK_FILL | !GTK_EXPAND,5);
   VDKBox* abox = new VDKBox(owner);
   VDKCheckButton* bt = new VDKCheckButton(owner,"A check button");
   abox->Add(bt);
   rb = new VDKRadioButton(owner,"A stand-alone radio button");
   abox->Add(rb);
-  table->AddToCell(abox,4,1,!GTK_FILL | !GTK_EXPAND,5);
+  table->AddToCell(abox,5,1,!GTK_FILL | !GTK_EXPAND,5);
   return table;
 }
 ////////////////////////////////////////////////////////////////////
@@ -593,7 +599,7 @@ void
 TestvdkForm::GUISetup(void)
 {
   int t = 0;
-  SetSize(650,450);
+  SetDefaultSize(VDKPoint(650,450));
   Title = "VDK 2.0.x Test";
   if(!GTK_WIDGET_REALIZED(Window()))
      gtk_widget_realize(Window());
@@ -623,7 +629,8 @@ TestvdkForm::GUISetup(void)
   // load test list model
   for(t=0; tests[t].test_name;t++)
     {
-      GtkTreeIter iter = *model->AppendBlank();
+      GtkTreeIter iter;
+      model->AppendBlank(&iter);
       model->SetCell(&iter,0,tests[t].test_name);
       model->SetCell(&iter,1,tests[t].tested ? "true" : "false");
     }
@@ -631,7 +638,9 @@ TestvdkForm::GUISetup(void)
   // stores max test numbers
   MAX_TEST = t;
   // select first row
-  testlist->SelectNode(model->Root());
+  GtkTreeIter iter;
+  if(model->Root(&iter))
+    testlist->SelectNode(&iter);
   scrolled->Add(testlist,l_justify,false,false,0);
   hbox2->Add(scrolled);
 
