@@ -43,24 +43,22 @@ VDKTreeViewModel::VDKTreeViewModel( GType* types, int ncol)
 }
 /*
  */
-GtkTreeIter*
-VDKTreeViewModel::AppendBlank(GtkTreeIter* parent = NULL)
+void
+VDKTreeViewModel::AppendBlank(GtkTreeIter* iter,GtkTreeIter* parent)
 {
-  gtk_tree_store_append (GTK_TREE_STORE (model), &iter, parent);
-  return &iter;
+  gtk_tree_store_append (GTK_TREE_STORE (model), iter, parent);
 }
 /*
  */
-GtkTreeIter*
-VDKTreeViewModel::PrependBlank(GtkTreeIter* parent = NULL)
+void
+VDKTreeViewModel::PrependBlank(GtkTreeIter* iter,GtkTreeIter* parent)
 {
-  gtk_tree_store_prepend (GTK_TREE_STORE (model), &iter, parent);
-  return &iter;
+  gtk_tree_store_prepend (GTK_TREE_STORE (model), iter, parent);
 }
 /*
  */
-GtkTreeIter*
-VDKTreeViewModel::InsertTuple(VDKTreeViewModelTuple &tuple, GtkTreeIter* parent, bool recurse)
+void
+VDKTreeViewModel::InsertTuple(GtkTreeIter* iter,VDKTreeViewModelTuple &tuple, GtkTreeIter* parent, bool recurse)
 {
   int t = 0;
   VDKTreeViewModelIterator ti(this,parent);
@@ -79,21 +77,24 @@ VDKTreeViewModel::InsertTuple(VDKTreeViewModelTuple &tuple, GtkTreeIter* parent,
       if(tuple < visited_tuple)
         {
           gtk_tree_store_insert_before (GTK_TREE_STORE(GtkModel()),
-                                             &iter,
+                                             iter,
                                              NULL,
                                              ti.current());
           for(t = 0; t < tuple.size(); t++)
-              SetCell(&iter,t,(char*) tuple[t]); 
-          return & iter;
+              SetCell(iter,t,(char*) tuple[t]); 
+          return ;
         }
       else if(recurse && ti.HasChild())
-	return InsertTuple(tuple, ti.current(),recurse);
+	{
+	 InsertTuple(iter,tuple, ti.current(),recurse);
+	 return;
+	}
     }
   // append to last node
-  iter = *AppendBlank(parent);
+  AppendBlank(iter,parent);
   for(t = 0; t < tuple.size(); t++)
-      SetCell(&iter,t,(char*) tuple[t]); 
-  return &iter;
+      SetCell(iter,t,(char*) tuple[t]); 
+  return ;
 }
 
 /*
@@ -101,8 +102,7 @@ VDKTreeViewModel::InsertTuple(VDKTreeViewModelTuple &tuple, GtkTreeIter* parent,
 void
 VDKTreeViewModel::Remove(GtkTreeIter* i)
 {
-  iter = *i;
-  gtk_tree_store_remove (GTK_TREE_STORE (model), &iter);
+  gtk_tree_store_remove (GTK_TREE_STORE (model), i);
   return ;
 }
 /*
@@ -130,23 +130,23 @@ VDKTreeViewModel::~VDKTreeViewModel()
 
 /*
  */
-GtkTreeIter*
-VDKTreeViewModel::Root()
+bool
+VDKTreeViewModel::Root(GtkTreeIter* iter)
 {
-  return gtk_tree_model_get_iter_root(GTK_TREE_MODEL(model),&iter) ? &iter : NULL;
+  return gtk_tree_model_get_iter_root(GTK_TREE_MODEL(model),iter) ? true : false;
 }
 /*
  */
-GtkTreeIter*
-VDKTreeViewModel::Next()
+bool
+VDKTreeViewModel::Next(GtkTreeIter* iter)
 {
-  return gtk_tree_model_iter_next(GTK_TREE_MODEL(model), &iter) ? &iter : NULL;
+  return gtk_tree_model_iter_next(GTK_TREE_MODEL(model), iter) ? true : false;
 }
 
-GtkTreeIter* 
-VDKTreeViewModel::Child(GtkTreeIter* parent)
+bool
+VDKTreeViewModel::Child(GtkTreeIter* iter,GtkTreeIter* parent)
 {
-  return gtk_tree_model_iter_children (GTK_TREE_MODEL(model), &iter, parent) ? &iter : NULL;
+  return gtk_tree_model_iter_children (GTK_TREE_MODEL(model), iter, parent) ? true : false;
 }
 
 /*
@@ -234,7 +234,14 @@ VDKTreeViewModel::GetCell(GtkTreeIter* node, int column)
 	sprintf(local,"%p",val);
       }
     default:
-      ;
+      {
+        if( type == GDK_TYPE_PIXBUF)
+	  {
+	    void* val = g_value_get_pointer(&value);
+	    local = new char[16];
+	    sprintf(local,"%p",val);
+	  }
+      }  
     }
   g_value_unset (&value);
   return local;
@@ -301,44 +308,41 @@ VDKTreeViewModel::SetCell(GtkTreeIter* node, int column, const char* val)
 }
 
 /*
-  linear search on tree (depth first)
+linear search on tree (depth first)
 */
-struct FIND_INFO
-  {
-    char* value;
-    GtkTreeIter* iter;
-    int column;
-    VDKTreeViewModel* vdkmodel;
-} find_info;
-
-
-static 
-gboolean fetch_iter  (GtkTreeModel *model,  GtkTreePath *path,  GtkTreeIter *iter, gpointer gp)
+static GtkTreeIter* 
+recurse(VDKTreeViewModel * model, int column, char* value, GtkTreeIter* iter)
 {
-  struct FIND_INFO * info = (struct FIND_INFO *) gp;// reinterpret_cast<find_info*>(gp);
-  char* value = info->vdkmodel->GetCell(iter,info->column);
-  if(value && !strcmp(value,info->value))
+  VDKTreeViewModelIterator ti(model,iter);
+  GtkTreeIter * found = NULL;
+  for(;ti;ti++)
     {
-      info->iter = iter;
-      delete[] value;
-      return TRUE;
+      char* visited_value = model->GetCell(ti.current(),column);
+      if(visited_value && !strcmp(value,visited_value))
+	{
+	  delete[] visited_value;
+	  found = ti.current();
+	  break;
+	}
+      else if(visited_value)
+	delete[] visited_value;
+      if(ti.HasChild())
+	{
+	  found = recurse (model,column,value,ti.current());
+	  if(found)
+	    break;
+	}
     }
-  else
-    return FALSE;
+  return found;
 }
 
 bool
 VDKTreeViewModel::Find(GtkTreeIter* iter,int column, char* value)
 {
-  struct FIND_INFO info;
-  info.value = value;
-  info.iter = NULL;
-  info.column = column;
-  info.vdkmodel = this;
-  gtk_tree_model_foreach (GTK_TREE_MODEL(model),fetch_iter, (gpointer) &info);
-  if(info.iter)
+  GtkTreeIter *found_iter = recurse(this,column,value,NULL);
+  if(found_iter)
     {
-      *iter = *info.iter;
+      *iter = *found_iter;
       return true;
     }
   else
@@ -491,6 +495,7 @@ VDKTreeViewColumn::VDKTreeViewColumn(VDKTreeView *owner, int col, char* title, b
 		   &VDKTreeViewColumn::SetNormalBackground),
   Foreground("Foreground",this,VDKRgb(-1,-1,-1),
 	     &VDKTreeViewColumn::SetForeground),
+  Font("Font",this,NULL,&VDKTreeViewColumn::SetFont),
   Title("Title",this,NULL,&VDKTreeViewColumn::SetTitle,&VDKTreeViewColumn::GetTitle),
   Width("Width",this,0,&VDKTreeViewColumn::SetWidth,&VDKTreeViewColumn::GetWidth),
   Sortable("Sortable",this,false,&VDKTreeViewColumn::SetSortable)
@@ -647,6 +652,36 @@ VDKTreeViewColumn::SetSortable(bool flag )
 /*
 
 
+                      VDKTREEVIEWITERATOR CLASS
+                      =========================
+
+*/
+bool 
+VDKTreeViewIter::Child(VDKTreeViewIter* child_iter)
+{
+  if(model && gtk_tree_model_iter_children(model,child_iter,this))
+    {
+      child_iter->Model(model);
+      return true;
+    }
+  else
+    return false;
+}
+
+bool 
+VDKTreeViewIter::Parent(VDKTreeViewIter* parent_iter)
+{
+  if (model && gtk_tree_model_iter_parent (model,parent_iter,this))
+    {
+      parent_iter->Model(model);
+      return true;
+    }
+  else
+    return false;
+}
+/*
+
+
                        VDKTREEVIEW CLASS
 
 
@@ -687,7 +722,8 @@ selection_cb (GtkTreeSelection *selection,
 	      gpointer     *gp)
 {
   VDKTreeView* tree = reinterpret_cast<VDKTreeView*>(gp);
-  VDKTreeViewIter iter;
+  VDKTreeViewModel *model = tree->Model;
+  VDKTreeViewIter iter(model ? GTK_TREE_MODEL(model->GtkModel()) : NULL);
   tree->Selections().flush();
   if (!gtk_tree_selection_get_selected (selection, NULL,&iter))
     return;
@@ -703,7 +739,7 @@ selection_cb (GtkTreeSelection *selection,
 static 
 void visit_selection  (GtkTreeModel *model,  GtkTreePath *path,  GtkTreeIter *iter, gpointer gp)
 {
-  VDKTreeViewIter i;
+  VDKTreeViewIter i(model);
   VDKTreeView* tree = reinterpret_cast<VDKTreeView*>(gp);
   //  gtk_tree_model_get_iter (model, &i, path);  
   /*
@@ -768,6 +804,8 @@ VDKTreeView::VDKTreeView(VDKForm* owner, VDKTreeViewModel* model, GtkSelectionMo
     case GTK_SELECTION_MULTIPLE:
       g_signal_connect_data (sigwid, "row_activated", G_CALLBACK (row_activated_cb), this, NULL,(GConnectFlags) 0);
       break;
+    case GTK_SELECTION_NONE:
+      break;
     }
 
 }
